@@ -12,17 +12,23 @@
 #'   (c) url to publicly available file;
 #'   in each case, this parameter identifies the source of the data for which
 #'   predictions will be calculated.
+#' @param forecastPoint character. Optional. The point relative to which predictions will be
+#'     generated, based on the forecast window of the project. Only specified in time series
+#'     projects.
 #' @param maxWait integer. The maximum time (in seconds) to wait for each of two steps:
 #'   (1) The initial dataset upload request, and
 #'   (2) data processing that occurs after receiving the response to this initial request.
-#' @return list with the following 6 components:
-#' \describe{
-#'   \item{id}{Character: string giving the unique alphanumeric identifier for the dataset}
-#'   \item{numColumns}{Numeric: number of columns in dataset}
-#'   \item{name}{Character: Name of dataset file}
-#'   \item{created}{Character: Time of upload}
-#'   \item{projectId}{Character: string giving the unique alphanumeric identifier for the project}
-#'   \item{numRows}{Numeric: number of rows in dataset}
+#' @return list with the following components:
+#' \itemize{
+#'   \item id character. The unique alphanumeric identifier for the dataset.
+#'   \item numColumns numeric. Number of columns in dataset.
+#'   \item name character. Name of dataset file.
+#'   \item created character. time of upload.
+#'   \item projectId character. String giving the unique alphanumeric identifier for the project.
+#'   \item numRows numeric. Number of rows in dataset.
+#'   \item forecastPoint character. The point relative to which predictions will be generated,
+#'     based on the forecast window of the project. Only specified in time series projects,
+#'     otherwise will be NULL.
 #' }
 #' @examples
 #' \dontrun{
@@ -30,7 +36,7 @@
 #'   UploadPredictionDataset(projectId, iris)
 #' }
 #' @export
-UploadPredictionDataset <- function(project, dataSource, maxWait = 600) {
+UploadPredictionDataset <- function(project, dataSource, forecastPoint = NULL, maxWait = 600) {
   projectId <- ValidateProject(project)
   if (isURL(dataSource)) {
     routeString <- UrlJoin("projects", projectId, "predictionDatasets", "urlUploads")
@@ -40,10 +46,13 @@ UploadPredictionDataset <- function(project, dataSource, maxWait = 600) {
     routeString <- UrlJoin("projects", projectId, "predictionDatasets", "fileUploads")
     dataList <- list(file = httr::upload_file(dataPath))
   }
+  if (!is.null(forecastPoint)) {
+    dataList$forecastPoint <- forecastPoint
+  }
   rawReturn <- DataRobotPOST(routeString, addUrl = TRUE, body = dataList,
                              returnRawResponse = TRUE, timeout = maxWait)
   asyncUrl <- httr::headers(rawReturn)$location
-  return(PredictionDatasetFromAsyncUrl(asyncUrl, maxWait = maxWait))
+  PredictionDatasetFromAsyncUrl(asyncUrl, maxWait = maxWait)
 }
 
 #' Retrieve prediction dataset info from the dataset creation URL
@@ -65,7 +74,7 @@ PredictionDatasetFromAsyncUrl <- function(asyncUrl, maxWait = 600) {
                                              maxWait = maxWait,
                                              failureStatuses = "ERROR"),
                           AsyncTimeout = function(e) stop(timeoutMessage))
-  return(datasetInfo)
+  datasetInfo
 }
 
 #' Retrieve all prediction datasets associated with a project
@@ -80,14 +89,17 @@ PredictionDatasetFromAsyncUrl <- function(asyncUrl, maxWait = 600) {
 #' @return An S3 object of class 'listDataRobotPredictionDataset', which is a
 #' list of dataframes: each element of the list corresponds to one
 #' prediction dataset associated with the project, and each dataframe has
-#' one row and the following 6 columns:
-#' \describe{
-#'   \item{id}{Character: string giving the unique alphanumeric identifier for the dataset}
-#'   \item{numColumns}{Numeric: number of columns in dataset}
-#'   \item{name}{Character: Name of dataset file}
-#'   \item{created}{Character: Time of upload}
-#'   \item{projectId}{Character: string giving the unique alphanumeric identifier for the project}
-#'   \item{numRows}{Numeric: number of rows in dataset}
+#' one row and the following columns:
+#' \itemize{
+#'   \item id character. The unique alphanumeric identifier for the dataset.
+#'   \item numColumns numeric. Number of columns in dataset.
+#'   \item name character. Name of dataset file.
+#'   \item created character. time of upload.
+#'   \item projectId character. String giving the unique alphanumeric identifier for the project.
+#'   \item numRows numeric. Number of rows in dataset.
+#'   \item forecastPoint. The point relative to which predictions will be generated, based on the
+#'     forecast window of the project. Only specified in time series projects, otherwise
+#'     will be NULL.
 #' }
 #' @examples
 #' \dontrun{
@@ -100,8 +112,8 @@ ListPredictionDatasets <- function(project) {
   routeString <- UrlJoin("projects", projectId, "predictionDatasets")
   datasetInfo <- DataRobotGET(routeString, addUrl = TRUE, simplifyDataFrame = FALSE)
   datasetlist <- datasetInfo$data
-  class(datasetlist) <- c('listOfDataRobotPredictionDatasets', 'listSubclass')
-  return(datasetlist)
+  class(datasetlist) <- c("listOfDataRobotPredictionDatasets", "listSubclass")
+  datasetlist
 }
 
 #' Delete a specified prediction dataset
@@ -123,7 +135,7 @@ DeletePredictionDataset <- function(project, datasetId) {
   projectId <- ValidateProject(project)
   routeString <- UrlJoin("projects", projectId, "predictionDatasets", datasetId)
   DataRobotDELETE(routeString, addUrl = TRUE)
-  return(invisible())
+  invisible(NULL)
 }
 
 #' Request predictions against a previously uploaded dataset
@@ -138,7 +150,7 @@ DeletePredictionDataset <- function(project, datasetId) {
 #' @examples
 #' \dontrun{
 #'   dataset <- UploadPredictionDataset(project, diamonds_small)
-#'   model <- GetAllModels(project)[[1]]
+#'   model <- ListModels(project)[[1]]
 #'   modelId <- model$modelId
 #'   predictJobId <- RequestPredictionsForDataset(project, modelId, dataset$id)
 #'   predictions <- GetPredictions(project, predictJobId)
@@ -150,5 +162,5 @@ RequestPredictionsForDataset <- function(project, modelId, datasetId) {
   dataList <- list(modelId = modelId, datasetId = datasetId)
   rawReturn <- DataRobotPOST(routeString, addUrl = TRUE, body = dataList,
                              returnRawResponse = TRUE)
-  return(JobIdFromResponse(rawReturn))
+  JobIdFromResponse(rawReturn)
 }
