@@ -13,26 +13,30 @@
 #'   both project and target, may be obtained with the function GetValidMetrics.
 #' @param weights character. Optional. String specifying the name of the column
 #'   from the modeling dataset to be used as weights in model fitting.
-#' @param partition Optional S3 object of class 'partition' whose elements specify
+#' @param partition partition. Optional. S3 object of class 'partition' whose elements specify
 #'   a valid partitioning scheme.  See help for functions CreateGroupPartition,
 #'   CreateRandomPartition, CreateStratifiedPartition, CreateUserPartition
 #'   and CreateDatetimePartitionSpecification.
+#' @param targetType character. Optional. Used to specify the targetType to use for a project when
+#'   it is ambiguous, i.e. a numeric target with a few unique values that could be used for either
+#'   regression or multiclass. Valid options are 'Binary', 'Multiclass', 'Regression'. See
+#'   \code{TargetType} for an easier way to keep track of the options.
 #' @param mode character. Optional. Specifies the autopilot mode used to start the
 #'   modeling project; valid options are 'auto' (fully automatic,
 #'   the current DataRobot default, obtained when mode = NULL), 'manual' and 'quick'
 #' @param seed integer. Optional. Seed for the random number generator used in
 #'   creating random partitions for model fitting.
-#' @param positiveClass Optional target variable value corresponding to a positive
+#' @param positiveClass character. Optional. Target variable value corresponding to a positive
 #'   response in binary classification problems.
 #' @param blueprintThreshold integer. Optional. The maximum time
 #'   (in hours) that any modeling blueprint is allowed to run before being
-#'   terminated.
+#'   excluded from subsequent autopilot stages.
 #' @param responseCap numeric. Optional. Floating point value, between 0.5 and 1.0,
 #'   specifying a capping limit for the response variable. The default value
 #'   NULL corresponds to an uncapped response, equivalent to responseCap = 1.0.
 #' @param quickrun logical. Optional. if TRUE then DR will perform
 #'   a quickrun, limiting the number of models evaluated during autopilot.
-#'   (quickrun flag is deprecated in 2.4, will be removed in 3.0)
+#'   (quickrun flag is deprecated in 2.4, will be removed in 2.10)
 #' @param featurelistId numeric. Specifies which feature list to use. If NULL (default),
 #'   a default featurelist is used.
 #' @param smartDownsampled logical. Optional. Whether to use smart downsampling to throw
@@ -41,6 +45,25 @@
 #' @param majorityDownsamplingRate numeric. Optional. Floating point value, between 0.0 and 100.0.
 #'   The percentage of the majority rows that should be kept.  Specify only if using smart
 #'   downsampling. May not cause the majority class to become smaller than the minority class.
+#' @param scaleoutModelingMode character. Optional. Specifies the behavior of Scaleout models
+#'   for the project. Possible options are in \code{ScaleoutModelingMode}.
+#'   \itemize{
+#'   \item \code{ScaleoutModelingMode$Disabled} will prevent scaleout models from running during
+#'     autopilot and will prevent Scaleout models from showing up in blueprints.
+#'   \item \code{ScaleoutModelingMode$RepositoryOnly} will prevent scaleout models from running
+#'     during autopilot, but will make them available in blueprints to run manually.
+#'   \item \code{ScaleoutModelingMode$Autopilot} will run scaleout models during autopilot and
+#'     will make them available in blueprints.
+#'   }
+#'   Note that scaleout models are only supported in the Hadoop environment with the correct
+#'   corresponding user permission set.
+#' @param accuracyOptimizedBlueprints logical. Optional. When enabled, accuracy optimized
+#'  blueprints will run in autopilot for the project. These are longer-running model blueprints
+#'  that provide increased accuracy over normal blueprints that run during autopilot.
+#' @param offset character. Optional. Vector of the names of the columns containing the offset of
+#'   each row.
+#' @param exposure character. Optional. The name of a column containing the exposure of each row.
+#' @param eventsCount character. Optional. The name of a column specifying the events count.
 #' @param maxWait integer. Specifies how many seconds to wait for the server to finish
 #'   analyzing the target and begin the modeling process. If the process takes
 #'   longer than this parameter specifies, execution will stop (but the server
@@ -51,81 +74,82 @@
 #'   SetTarget(projectId, "targetFeature")
 #'   SetTarget(projectId, "targetFeature", metric = "LogLoss")
 #'   SetTarget(projectId, "targetFeature", mode = AutopilotMode$Manual)
+#'   SetTarget(projectId, "targetFeature", targetType = TargetType$Multiclass)
 #' }
 #' @export
 SetTarget <- function(project, target, metric = NULL, weights = NULL,
-                      partition = NULL, mode = NULL, seed = NULL,
+                      partition = NULL, mode = NULL, seed = NULL, targetType = NULL,
                       positiveClass = NULL, blueprintThreshold = NULL,
                       responseCap = NULL, quickrun = NULL, featurelistId = NULL,
                       smartDownsampled = NULL, majorityDownsamplingRate = NULL,
-                      maxWait = 600) {
-
+                      scaleoutModelingMode = NULL, accuracyOptimizedBlueprints = NULL,
+                      offset = NULL, exposure = NULL, eventsCount = NULL, maxWait = 600) {
   if (is.null(target)) {
     stop("No target variable specified - cannot start Autopilot")
-  } else {
-    if (!is.null(quickrun)) {
-      Deprecated("quickrun flag (use quick autopilot mode instead)", "2.4", "3.0")
-    }
-
-    if (!is.null(mode) && mode == AutopilotMode$Quick) {
-      mode <- AutopilotMode$FullAuto
-      quickrun <- TRUE
-    }
-
-    projectId <- ValidateProject(project)
-    routeString <- UrlJoin("projects", projectId, "aim")
-    pStat <- GetProjectStatus(projectId)
-    stage <- as.character(pStat[which(names(pStat) == "stage")])
-    if (stage != "aim") {
-      errorMsg <- paste("Autopilot stage is", stage,
-                        "but it must be 'aim' to set the target and start a new project")
-      stop(strwrap(errorMsg))
-    }
-
-    bodyList <- list(target = target)
-    bodyList$metric <- metric
-    bodyList$weights <- weights
-    if (is.numeric(mode)) {
-      Deprecated("Numeric modes (use e.g. AutopilotMode$FullAuto instead)", "2.1", "3.0")
-    }
-    bodyList$mode <- mode
-    bodyList$seed <- seed
-    bodyList$positiveClass <- positiveClass
-    bodyList$blueprintThreshold <- blueprintThreshold
-    bodyList$responseCap <- responseCap
-    bodyList$quickrun <- quickrun
-    bodyList$featurelistId <- featurelistId
-    bodyList$smartDownsampled <- smartDownsampled
-    bodyList$majorityDownsamplingRate <- majorityDownsamplingRate
-    if (!is.null(partition)) {
-      if (partition$cvMethod == cvMethods$DATETIME) {
-        partition <- as.dataRobotDatetimePartitionSpecification(partition)
-      }
-      bodyList <- append(bodyList, partition)
-    }
-    #
-    #  Note that partitionKeyCols element, if present, must be passed as a
-    #  list instead of a character string. Test for this case and apply the
-    #  messy special handling required if this element is present
-    #
-    if (length(bodyList$partitionKeyCols) == 0) {
-      if (exists('cvMethod', where = bodyList) && bodyList$cvMethod == cvMethods$DATETIME
-          && !is.null(bodyList$backtests)) {
-        body <- FormatMixedList(bodyList, specialCase = 'backtests')
-      } else {
-        body <- jsonlite::unbox(as.data.frame(bodyList))
-      }
-    } else {
-      body <- FormatMixedList(bodyList, specialCase = 'partitionKeyCols')
-    }
-    response <- DataRobotPATCH(routeString, addUrl = TRUE, body = body, returnRawResponse = TRUE,
-                               encode = 'json')
-    WaitForAsyncReturn(httr::headers(response)$location,
-                       addUrl = FALSE,
-                       maxWait = maxWait,
-                       failureStatuses = "ERROR")
-    message("Autopilot started")
   }
+  if (!is.null(quickrun)) {
+    Deprecated("quickrun flag (use quick autopilot mode instead)", "2.4", "2.10")
+  }
+
+  if (!is.null(mode) && mode == AutopilotMode$Quick) {
+    mode <- AutopilotMode$FullAuto
+    quickrun <- TRUE
+  }
+
+  projectId <- ValidateProject(project)
+  routeString <- UrlJoin("projects", projectId, "aim")
+  pStat <- GetProjectStatus(projectId)
+  stage <- as.character(pStat[which(names(pStat) == "stage")])
+  if (stage != "aim") {
+    errorMsg <- paste("Autopilot stage is", stage,
+                      "but it must be 'aim' to set the target and start a new project")
+    stop(strwrap(errorMsg))
+  }
+
+  bodyList <- list(target = target)
+  bodyList$metric <- metric
+  bodyList$weights <- weights
+  if (is.numeric(mode)) {
+    Deprecated("Numeric modes (use e.g. AutopilotMode$FullAuto instead)", "2.1", "2.10")
+  }
+  bodyList$mode <- mode
+  bodyList$seed <- seed
+  bodyList$positiveClass <- positiveClass
+  bodyList$blueprintThreshold <- blueprintThreshold
+  bodyList$responseCap <- responseCap
+  bodyList$quickrun <- quickrun
+  bodyList$featurelistId <- featurelistId
+  bodyList$smartDownsampled <- smartDownsampled
+  bodyList$majorityDownsamplingRate <- majorityDownsamplingRate
+  bodyList$scaleoutModelingMode <- scaleoutModelingMode
+  bodyList$accuracyOptimizedMb <- accuracyOptimizedBlueprints
+  bodyList$offset <- offset
+  bodyList$exposure <- exposure
+  bodyList$eventsCount <- eventsCount
+  ValidateParameterIn(targetType, TargetType)
+  bodyList$targetType <- targetType
+
+  if (!is.null(partition)) {
+    if (partition$cvMethod == cvMethods$DATETIME) {
+      partition <- as.dataRobotDatetimePartitionSpecification(partition)
+    }
+    bodyList <- append(bodyList, partition)
+  }
+
+  Unbox <- function(x) {
+    if (length(x) == 1 && !is.list(x)) { jsonlite::unbox(x) }
+    else { x }
+  }
+  response <- DataRobotPATCH(routeString,
+                             addUrl = TRUE,
+                             body = lapply(bodyList, Unbox),
+                             returnRawResponse = TRUE,
+                             encode = "json")
+  WaitForAsyncReturn(httr::headers(response)$location,
+                     addUrl = FALSE,
+                     maxWait = maxWait,
+                     failureStatuses = "ERROR")
+  message("Autopilot started")
 }
 
 #' Starts autopilot on provided featurelist.
@@ -147,7 +171,7 @@ SetTarget <- function(project, target, metric = NULL, weights = NULL,
 #' @examples
 #' \dontrun{
 #'   projectId <- "59a5af20c80891534e3c2bde"
-#'   featureList <- CreateFeatureList(projectId, "myFeaturelist", c("feature1", "feature2"))
+#'   featureList <- CreateFeaturelist(projectId, "myFeaturelist", c("feature1", "feature2"))
 #'   featurelistId <- featureList$featurelistId
 #'   StartNewAutoPilot(projectId, featurelistId)
 #' }
